=== modified file 'ChangeLog'
--- ChangeLog	2006-08-08 14:44:53 +0000
+++ ChangeLog	2006-08-08 18:32:32 +0000
@@ -1,4 +1,9 @@
 2006-08-08  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
+    * olive/frontend/gtk/menu.py: Added left context menu + Bookmark option
+    * olive/frontend/gtk/__init__.py: load bookmarks into the left panel
+    * olive/frontend/gtk/handler.py: implemented signal handlers for left panel
+    * olive.glade: added signals for the bookmark TreeView
+    * cmenu.ui: added description for bookmark context menu
     * olive/frontend/gtk/__init__.py: implemented OlivePreferences - this class
       is responsible for loading/saving user preferences
     * olive/frontend/gtk/handler.py: save preferences before quit

=== modified file 'TODO'
--- TODO	2006-08-08 14:44:53 +0000
+++ TODO	2006-08-08 18:32:32 +0000
@@ -10,3 +10,4 @@
  - Display the commit file selector as a tree (so whole directories can be
    toggled) (j-a-meinel)
  - "Probe location" button on the Push dialog (test write access, etc.) (ddaa)
+ - Save and restore main window position and size (phanatic)

=== modified file 'cmenu.ui'
--- cmenu.ui	2006-08-02 20:35:25 +0000
+++ cmenu.ui	2006-08-08 18:32:32 +0000
@@ -7,5 +7,10 @@
         <separator />
         <menuitem name="diff" action="diff" />
         <menuitem name="log" action="log" />
+        <separator />
+        <menuitem name="bookmark" action="bookmark" />
+    </popup>
+    <popup name="context_left">
+        <menuitem name="remove_bookmark" action="remove_bookmark" />
     </popup>
 </ui>

=== modified file 'olive.glade'
--- olive.glade	2006-08-08 14:44:53 +0000
+++ olive.glade	2006-08-08 18:32:32 +0000
@@ -514,6 +514,8 @@
 		  <property name="fixed_height_mode">False</property>
 		  <property name="hover_selection">False</property>
 		  <property name="hover_expand">False</property>
+		  <signal name="row_activated" handler="on_treeview_left_row_activated" last_modification_time="Tue, 08 Aug 2006 15:31:09 GMT"/>
+		  <signal name="button_press_event" handler="on_treeview_left_button_press_event" last_modification_time="Tue, 08 Aug 2006 15:31:15 GMT"/>
 		</widget>
 	      </child>
 	    </widget>

=== modified file 'olive/frontend/gtk/__init__.py'
--- olive/frontend/gtk/__init__.py	2006-08-08 14:44:53 +0000
+++ olive/frontend/gtk/__init__.py	2006-08-08 18:32:32 +0000
@@ -14,6 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import ConfigParser
 import os
 import os.path
 import sys
@@ -78,7 +79,9 @@
                 "on_toolbutton_pull_clicked": handler.not_implemented,
                 "on_toolbutton_push_clicked": handler.on_menuitem_branch_push_activate,
                 "on_treeview_right_button_press_event": handler.on_treeview_right_button_press_event,
-                "on_treeview_right_row_activated": handler.on_treeview_right_row_activated }
+                "on_treeview_right_row_activated": handler.on_treeview_right_row_activated,
+                "on_treeview_left_button_press_event": handler.on_treeview_left_button_press_event,
+                "on_treeview_left_row_activated": handler.on_treeview_left_row_activated }
         
         # Connect the signals to the handlers
         self.toplevel.signal_autoconnect(dic)
@@ -91,7 +94,34 @@
         
     def _load_left(self):
         """ Load data into the left panel. (Bookmarks) """
-        pass
+        # set cursor to busy
+        self.comm.set_busy(self.treeview_left)
+        
+        # Create TreeStore
+        treestore = gtk.TreeStore(str)
+        
+        # Get bookmarks
+        bookmarks = self.comm.pref.get_bookmarks()
+        
+        # Add them to the TreeStore
+        titer = treestore.append(None, ['Bookmarks'])
+        for item in bookmarks:
+            treestore.append(titer, [item])
+        
+        # Create the column and add it to the TreeView
+        self.treeview_left.set_model(treestore)
+        tvcolumn_bookmark = gtk.TreeViewColumn('Bookmark')
+        self.treeview_left.append_column(tvcolumn_bookmark)
+        
+        # Set up the cells
+        cell = gtk.CellRendererText()
+        tvcolumn_bookmark.pack_start(cell, True)
+        tvcolumn_bookmark.add_attribute(cell, 'text', 0)
+        
+        # Expand the tree
+        self.treeview_left.expand_all()
+        
+        self.comm.set_busy(self.treeview_left, False)
         
     def _load_right(self):
         """ Load data into the right panel. (Filelist) """
@@ -185,6 +215,16 @@
             return None
         else:
             return model.get_value(iter, 1)
+    
+    def get_selected_left(self):
+        """ Get the selected bookmark. """
+        treeselection = self.treeview_left.get_selection()
+        (model, iter) = treeselection.get_selected()
+        
+        if iter is None:
+            return None
+        else:
+            return model.get_value(iter, 0)
 
     def set_statusbar(self, message):
         """ Set the statusbar message. """
@@ -194,6 +234,31 @@
         """ Clean the last message from the statusbar. """
         self.statusbar.pop(self.context_id)
     
+    def refresh_left(self):
+        """ Refresh the bookmark list. """
+        # set cursor to busy
+        self.set_busy(self.treeview_left)
+        
+        # Get TreeStore and clear it
+        treestore = self.treeview_left.get_model()
+        treestore.clear()
+        
+        # Get bookmarks
+        bookmarks = self.pref.get_bookmarks()
+        
+        # Add them to the TreeStore
+        titer = treestore.append(None, ['Bookmarks'])
+        for item in bookmarks:
+            treestore.append(titer, [item])
+        
+        # Add the TreeStore to the TreeView
+        self.treeview_left.set_model(treestore)
+        
+        # Expand the tree
+        self.treeview_left.expand_all()
+        
+        self.set_busy(self.treeview_left, False)
+    
     def refresh_right(self, path=None):
         """ Refresh the file list. """
         import olive.backend.fileops as fileops
@@ -247,8 +312,6 @@
     """ A class which handles Olive's preferences. """
     def __init__(self):
         """ Initialize the Preferences class. """
-        import ConfigParser
-        
         # Some default options
         self.defaults = { 'strict_commit': False,
                           'dotted_files' : False }
@@ -336,11 +399,11 @@
         """ Add bookmark. """
         try:
             self.config.add_section(path)
-        except DuplicateSectionError:
+        except ConfigParser.DuplicateSectionError:
             return False
         else:
             return True
 
-    def del_bookmark(self, path):
+    def remove_bookmark(self, path):
         """ Remove bookmark. """
         return self.config.remove_section(path)

=== modified file 'olive/frontend/gtk/handler.py'
--- olive/frontend/gtk/handler.py	2006-08-08 14:44:53 +0000
+++ olive/frontend/gtk/handler.py	2006-08-08 18:32:32 +0000
@@ -107,6 +107,24 @@
         diff = OliveDiff(self.gladefile, self.comm)
         diff.display()
     
+    def on_treeview_left_button_press_event(self, widget, event):
+        """ Occurs when somebody right-clicks in the bookmark list. """
+        if event.button == 3:
+            self.menu.left_context_menu().popup(None, None, None, 0,
+                                                 event.time)
+        
+    def on_treeview_left_row_activated(self, treeview, path, view_column):
+        """ Occurs when somebody double-clicks or enters an item in the
+        bookmark list. """
+        self.comm.set_busy(treeview)
+        
+        newdir = self.comm.get_selected_left()
+        self.comm.set_path(newdir)
+        
+        self.comm.refresh_right()
+        
+        self.comm.set_busy(treeview, False)
+    
     def on_treeview_right_button_press_event(self, widget, event):
         """ Occurs when somebody right-clicks in the file list. """
         if event.button == 3:

=== modified file 'olive/frontend/gtk/menu.py'
--- olive/frontend/gtk/menu.py	2006-08-03 10:14:44 +0000
+++ olive/frontend/gtk/menu.py	2006-08-08 18:32:32 +0000
@@ -47,38 +47,53 @@
         self.comm = comm
         self.dialog = dialog
         
-        self.ui_right = gtk.UIManager()
-        
-        self.actiongroup_right = gtk.ActionGroup('context_right')
-        self.actiongroup_right.add_actions([('add', gtk.STOCK_ADD,
-                                             'Add', None,
-                                             'Add the selected file',
-                                             self.add_file),
-                                            ('remove', gtk.STOCK_REMOVE,
-                                             'Remove', None,
-                                             'Remove the selected file',
-                                             self.remove_file),
-                                            ('commit', gtk.STOCK_REDO,
-                                             'Commit', None,
-                                             'Commit the changes',
-                                             self.commit),
-                                            ('diff', None,
-                                             'Diff', None,
-                                             'Show the diff of the file',
-                                             self.diff),
-                                            ('log', None,
-                                             'Log', None,
-                                             'Show the log of the file',
-                                             self.log)])
-        
-        self.ui_right.insert_action_group(self.actiongroup_right, 0)
-        self.ui_right.add_ui_from_file(self.uifile)
-        
-        self.cmenu_right = self.ui_right.get_widget('/context_right')
+        # Create the file list context menu
+        self.ui = gtk.UIManager()
+        
+        self.actiongroup = gtk.ActionGroup('context')
+        self.actiongroup.add_actions([('add', gtk.STOCK_ADD,
+                                       'Add', None,
+                                       'Add the selected file',
+                                       self.add_file),
+                                      ('remove', gtk.STOCK_REMOVE,
+                                       'Remove', None,
+                                       'Remove the selected file',
+                                       self.remove_file),
+                                      ('commit', gtk.STOCK_REDO,
+                                       'Commit', None,
+                                       'Commit the changes',
+                                       self.commit),
+                                      ('diff', None,
+                                       'Diff', None,
+                                       'Show the diff of the file',
+                                       self.diff),
+                                      ('log', None,
+                                       'Log', None,
+                                       'Show the log of the file',
+                                       self.log),
+                                      ('bookmark', None,
+                                       'Bookmark', None,
+                                       'Bookmark current location',
+                                       self.bookmark),
+                                      ('remove_bookmark', gtk.STOCK_REMOVE,
+                                       'Remove', None,
+                                       'Remove the selected bookmark',
+                                       self.remove_bookmark)
+                                     ])
+        
+        self.ui.insert_action_group(self.actiongroup, 0)
+        self.ui.add_ui_from_file(self.uifile)
+        
+        self.cmenu_right = self.ui.get_widget('/context_right')
+        
+        self.cmenu_left = self.ui.get_widget('/context_left')
 
     def right_context_menu(self):
         return self.cmenu_right
     
+    def left_context_menu(self):
+        return self.cmenu_left
+    
     def add_file(self, action):
         """ Right context menu -> Add """
         # Add only the selected file
@@ -135,3 +150,18 @@
     def log(self, action):
         """ Right context menu -> Log """
         self.dialog.error_dialog('This feature is not yet implemented.')
+    
+    def bookmark(self, action):
+        """ Right context menu -> Bookmark """
+        if self.comm.pref.add_bookmark(self.comm.get_path()):
+            self.dialog.info_dialog('Bookmark successfully added.')
+        else:
+            self.dialog.warning_dialog('Location already bookmarked.')
+        
+        self.comm.refresh_left()
+
+    def remove_bookmark(self, action):
+        """ Left context menu -> Remove """
+        self.comm.pref.remove_bookmark(self.comm.get_selected_left())
+        
+        self.comm.refresh_left()

